@@ -166,7 +166,7 @@ qx.Class.define("callbackery.ui.form.VirtualSelectBox",
       let selection = this.getSelection();
       if (item !== null && item !== undefined) {
         try {
-            selection.setItem(0,selected);
+            selection.setItem(0,item);
             return true;
         }
         catch(e) {
